return {
    { -- use bdelete instead
        "https://github.com/famiu/bufdelete.nvim",
        config = function()
            -- switches to Alpha dashboard when last buffer is closed
            local alpha_on_empty = vim.api.nvim_create_augroup("alpha_on_empty", { clear = true })
            vim.api.nvim_create_autocmd("User", {
                pattern = "BDeletePost*",
                group = alpha_on_empty,
                callback = function(event)
                    local fallback_name = vim.api.nvim_buf_get_name(event.buf)
                    local fallback_ft = vim.api.nvim_buf_get_option(event.buf, "filetype")
                    local fallback_on_empty = fallback_name == "" and fallback_ft == ""
                    if fallback_on_empty then
                        require("neo-tree").close_all()
                        vim.cmd("Alpha")
                        vim.cmd(event.buf .. "bwipeout")
                    end
                end,
            })
        end,
        keys = {
            { "<leader>bd", "<CMD>Bdelete<CR>", desc = "delete buffer" },
            { "<leader>bD", "<CMD>Bdelete!<CR>", desc = "delete buffer!" },
        },
    },
    { -- neo-tree file explorer
        "https://github.com/nvim-neo-tree/neo-tree.nvim",
        cmd = "Neotree",
        keys = {
            { "<leader>fe", "<cmd>Neotree toggle<cr>", desc = "file explorer toggle" },
            {
                "<leader>ge",
                function()
                    require("neo-tree.command").execute({
                        source = "git_status",
                        toggle = true
                    })
                end,
                desc = "git explorer",
            },
            {
                "<leader>be",
                function()
                    require("neo-tree.command").execute({
                        source = "buffers",
                        toggle = true
                    })
                end,
                desc = "buffer explorer",
            },
        },
        dependencies = {
            "https://github.com/nvim-lua/plenary.nvim",
            "https://github.com/MunifTanjim/nui.nvim",
            "https://github.com/kyazdani42/nvim-web-devicons",
        },
        opts = {
            close_if_last_window = true,
            filesystem = {
                hijack_netrw_behavior = "open_default",
            },
        },
    },
    {
        'stevearc/oil.nvim',
        dependencies = {
            "nvim-tree/nvim-web-devicons"
        }, -- use if you prefer nvim-web-devicons
        opts = {},
        lazy = false,
    },
    { -- a fast motion inside a visible area
        "https://github.com/ggandor/leap.nvim",
        event = "BufReadPre",
        config = function()
            local leap = require("leap")
            leap.add_default_mappings(true)
        end,
    },
    { -- bookmark files
        "https://github.com/otavioschwanck/arrow.nvim",
        event = "BufReadPre",
        opts = {
            show_icons = true,
            leader_key = '<leader>H',
            buffer_leader_key = '<leader>h',
        }
    },
    { -- displays a popup with possible key bindings
        "https://github.com/folke/which-key.nvim",
        event = "VeryLazy",
        dependencies = {
            "https://github.com/kyazdani42/nvim-web-devicons",
        },
        opts = {
            preset = "helix",
            spec = {
                { "<leader>b",  group = "buffer" },
                { "<leader>g",  group = "git" },
                { "<leader>gd", group = "diff" },
                { "<leader>gr", group = "reset" },
                { "<leader>gs", group = "stage" },
                { "<leader>gt", group = "toggle" },
                { "<leader>p", group = "pick" },
                { "<leader>u",  group = "ui" },
                { "<leader>x",  group = "diagnostics" },
            },
        },
    },
    { -- better diagnostics list and others
        "https://github.com/folke/trouble.nvim",
        cmd = "Trouble",
        keys = {
            {
                "<leader>xx",
                "<cmd>Trouble diagnostics toggle<cr>",
                desc = "Diagnostics (Trouble)",
            },
            {
                "<leader>xX",
                "<cmd>Trouble diagnostics toggle filter.buf=0<cr>",
                desc = "Buffer Diagnostics (Trouble)",
            },
            {
                "<leader>cs",
                "<cmd>Trouble symbols toggle focus=false<cr>",
                desc = "Symbols (Trouble)",
            },
            {
                "<leader>cl",
                "<cmd>Trouble lsp toggle focus=false win.position=right<cr>",
                desc = "LSP Definitions / references / ... (Trouble)",
            },
            {
                "<leader>xL",
                "<cmd>Trouble loclist toggle<cr>",
                desc = "Location List (Trouble)",
            },
            {
                "<leader>xQ",
                "<cmd>Trouble qflist toggle<cr>",
                desc = "Quickfix List (Trouble)",
            },
        },
        opts = {
            use_diagnostic_signs = true,
        },
    },
    { -- todo comments
        "https://github.com/folke/todo-comments.nvim",
        dependencies = {
            "https://github.com/nvim-lua/plenary.nvim",
        },
        cmd = { "TodoTrouble" },
        event = "BufReadPost",
        keys = {
            {
                "]t",
                function()
                    require("todo-comments").jump_next()
                end,
                desc = "next todo comment",
            },
            {
                "[t",
                function()
                    require("todo-comments").jump_prev()
                end,
                desc = "previous todo comment",
            },
            {
                "<leader>xt",
                "<cmd>TodoTrouble<cr>",
                desc = "todo (trouble)"
            },
        },
        config = true,
    },
    { -- better folding
        "https://github.com/kevinhwang91/nvim-ufo",
        dependencies = {
            "https://github.com/kevinhwang91/promise-async",
        },
        event = "BufReadPost",
        keys = {
            {
                "zR",
                function ()
                    require('ufo').openAllFolds()
                end,
                desc = "Open all folds"
            },
            {
                "zM",
                function ()
                    require('ufo').closeAllFolds()
                end,
                desc = "Close all folds"
            },
        },
        config = {
            provider_selector = function(bufnr, filetype, buftype)
                return {'treesitter', 'indent'}
            end
        },
    },
    { -- rainbow delimiters
        "https://gitlab.com/HiPhish/rainbow-delimiters.nvim",
        event = "BufReadPost",
    },
    { -- show colors
        "https://github.com/norcalli/nvim-colorizer.lua",
        ft = { "html", "css", "scss", },
        keys = {
            {
                "<leader>uh",
                "<CMD>ColorizerToggle<CR>",
                desc = "Toggle background colors rendering",
            },
        },
        config = true,
    },
    {
        "folke/persistence.nvim",
        event = "BufReadPre", -- this will only start session saving when an actual file was opened
        keys = {
            {"<leader>qs", function() require("persistence").load() end, desc = "load session from cwd"},
            {"<leader>qS", function() require("persistence").select() end, desc = "select a session to load"},
            {"<leader>ql", function() require("persistence").load({ last = true }) end, desc = "load te last session"},
            {"<leader>qd", function() require("persistence").stop() end, desc = "stop persistence"},
        },
        opts = {
            -- add any custom options here
        }
    },
}
